pub struct GetExtendedStatus;Trait Implementations
Sourceimpl Archive for GetExtendedStatus
impl Archive for GetExtendedStatus
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetExtendedStatus
type Archived = ArchivedGetExtendedStatus
The archived representation of this type. Read more
Sourcetype Resolver = GetExtendedStatusResolver
type Resolver = GetExtendedStatusResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetExtendedStatus
impl BlockingArchive for GetExtendedStatus
Sourcetype Response = Option<ExtendedStatus>
type Response = Option<ExtendedStatus>
response type for this message
Sourceimpl Debug for GetExtendedStatus
impl Debug for GetExtendedStatus
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetExtendedStatus, __D> for Archived<GetExtendedStatus>
impl<__D: Fallible + ?Sized> Deserialize<GetExtendedStatus, __D> for Archived<GetExtendedStatus>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetExtendedStatus, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetExtendedStatus, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetExtendedStatus
impl MessageId for GetExtendedStatus